| Plone Intranet

Reset filters

Document types PowerPoint12 Word12 Excel11 Folder2 Link11 Task2 Question11 PDF11 People9 Post9 Rich pages8 News items8 Library items7 Library section1 Events7 Images5 Slideshows4 Workspaces1 Super space1
Date range
Tags Deliberable Minutes Meetings Operations Protocol Workflow Project management Legal All other tags

87 items matched your search. Options

Display previews
Sort by relevancy Sort by date

Did you mean Mini?

Baggage Archived

  #### Super space name

  Lorem ipsum dolor sit.

  /workpspaces/baggage/
Some case

  #### Super space name

  Lorem ipsum dolor sit.

  /workpspaces/baggage/
Regular workspace

  #### Super space name

  Lorem ipsum dolor sit.

  /workpspaces/baggage/
Janet Northcote posted 9 minutes ago

  #### Post contents

  Star Alliance Instagram account hits 20k followers Star Alliance's Instagram account, launched just four months ago on the Alliance`s 18th birt…

  /posts/2307540960981987527368
MinistrantInnen-Fest vom 7. September 2014 in St. Gallen

  #### Worksspace name

  Nicht budgetierte einmalige Beiträge. Verein DAMP. Finanzielle Unterstützung des MinistrantInnen-Fest vom 7. September …

  /minifest
Zusage DAMP Minifest

  Der Synodalrat hat an seiner Sitzung vom 3. Februar 2014 beschlossen, dem Verein DAMP für die Durchführung des Mini-Fes…

  /zusage
Antrag RT Minifest 2014

  Lorem ipsum dolor sit amet

  /antrag-minifest
Stellungnahme Generalvikar Minifest

  /stellungnahme-generalvikar
Mario Minstreel

  #### Mario

  /mario-minstreel
The Gerald Aylmer seminar 2015: Secret histories
  16 September 2015

  How do archivists and historians deal with secrets? How do secrets impact family and personal narratives? How do we dea…

  /event-gerald-aylmer-seminar
Camille Fermin

  #### Camille

  Liz Baker combines an integral business perspective, with in-depth technical expertise. He is passionate about innovati…

  /camille-fermin
Minutes of 2014-06-09

  # Minutes of our meeting on 2014-06-09

  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent sollicitudin felis a quam sagittis adipiscing. Praesent nulla sapien, lacinia a lectus sit amet, fermentum fermentum eros.

  Number | First Name | Last Name | Points
  --- | --- | --- | ---
  1 | Eve | Jackson | 94
  2 | John | Doe | 80
  3 | Adam | Johnson | 67

  Nullam eget mi consectetur, suscipit arcu et, tincidunt nisl. Phasellus feugiat, eros id vestibulum vestibulum, est ligula ultrices erat, sit amet vulputate est ligula sed nisl. Duis ac tincidunt diam.

  1. For the first
  2. Second, we need to do it
  3. And third, this has been decided.

      &lt;p&gt;This is a great code example.&lt;/p&gt;

  Donec placerat sem commodo orci placerat, eu hendrerit urna bibendum. Nam a orci a neque sollicitudin ornare in ac est.

  Aenean adipiscing ante eget blandit vehicula. Phasellus luctus, dui vestibulum molestie volutpat, quam libero eleifend ante, ac porta nulla urna sit amet arcu. Ut et sagittis orci.

  - Proin condimentum
  - Nisi enim
  - Non feugiat elit varius
  - Cras aliquam sit
  - Amet nunc in consequat

  Etiam nec ipsum ullamcorper, porttitor mi et, ultrices enim. Curabitur adipiscing urna at dui placerat, in sodales ligula luctus. Nullam et fermentum lorem, at mattis massa. Integer venenatis pharetra velit, vel fringilla tellus lacinia quis. Ut porttitor vestibulum enim quis molestie. Sed et sem eget sapien adipiscing blandit. Ut ornare tellus eu neque porttitor bibendum. Duis consectetur dui ut pulvinar vehicula. In nec semper nisi. Duis posuere iaculis varius.

  Mauris et mauris metus. Vestibulum tincidunt pharetra erat eget malesuada. Proin sed magna mollis, suscipit est nec, elementum magna. In euismod posuere ligula in imperdiet. Mauris lobortis nisi nec tempor consectetur. Quisque venenatis augue ante, non tincidunt metus facilisis fermentum. Aenean pellentesque at massa sit amet condimentum. Aliquam sit amet tincidunt tortor, ac elementum leo. Sed elementum arcu eget tellus facilisis, quis lobortis nibh faucibus. Vestibulum in urna pretium, convallis tellus vel, tincidunt quam. Donec ut magna quis justo vestibulum faucibus quis at velit. Aliquam laoreet ligula congue nisi dignissim, eu vestibulum urna dignissim.

  Donec vehicula eleifend est quis malesuada. Nam tristique placerat eros et semper. Mauris vel risus adipiscing, faucibus magna in, commodo dui. Aliquam sagittis non nibh ut faucibus. Nunc blandit orci et porttitor elementum. Aenean commodo nisi in facilisis tempus. Duis arcu eros, vehicula vitae auctor nec, vestibulum ac sem. Proin sed feugiat turpis. Vivamus aliquet tincidunt vestibulum. Cras rhoncus mauris libero, ut porttitor ante hendrerit sit amet. Proin ultrices rhoncus iaculis. Etiam eget lectus metus. Nullam varius metus euismod risus consequat imperdiet.

  Vivamus et accumsan magna. Ut arcu sapien, vehicula at nisi et, tincidunt consectetur turpis. Pellentesque auctor nibh vel diam fermentum viverra. In elementum tortor diam, in tincidunt orci sollicitudin feugiat. Fusce volutpat vulputate tortor, eu feugiat tellus vestibulum sed. Vivamus fringilla erat ante, vitae volutpat quam pulvinar vel. Maecenas nec lectus nec dolor ornare consectetur.

  Follow

  Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui…

  /minutes-of-2014-06-09
Minutes of 2014-05-03

  # Minutes of meeting on 2014-05-03

  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent sollicitudin felis a quam sagittis adipiscing. Praesent nulla sapien, lacinia a lectus sit amet, fermentum fermentum eros. Nullam eget mi consectetur, suscipit arcu et, tincidunt nisl. Phasellus feugiat, eros id vestibulum vestibulum, est ligula ultrices erat, sit amet vulputate est ligula sed nisl. Duis ac tincidunt diam. Donec placerat sem commodo orci placerat, eu hendrerit urna bibendum. Nam a orci a neque sollicitudin ornare in ac est.

  Aenean adipiscing ante eget blandit vehicula. Phasellus luctus, dui vestibulum molestie volutpat, quam libero eleifend ante, ac porta nulla urna sit amet arcu. Ut et sagittis orci.

  - Proin condimentum
  - Nisi enim
  - Non feugiat elit varius
  - Cras aliquam sit
  - Amet nunc in consequat

  Etiam nec ipsum ullamcorper, porttitor mi et, ultrices enim. Curabitur adipiscing urna at dui placerat, in sodales ligula luctus. Nullam et fermentum lorem, at mattis massa. Integer venenatis pharetra velit, vel fringilla tellus lacinia quis. Ut porttitor vestibulum enim quis molestie. Sed et sem eget sapien adipiscing blandit. Ut ornare tellus eu neque porttitor bibendum. Duis consectetur dui ut pulvinar vehicula. In nec semper nisi. Duis posuere iaculis varius.

  Mauris et mauris metus. Vestibulum tincidunt pharetra erat eget malesuada. Proin sed magna mollis, suscipit est nec, elementum magna. In euismod posuere ligula in imperdiet. Mauris lobortis nisi nec tempor consectetur. Quisque venenatis augue ante, non tincidunt metus facilisis fermentum. Aenean pellentesque at massa sit amet condimentum. Aliquam sit amet tincidunt tortor, ac elementum leo. Sed elementum arcu eget tellus facilisis, quis lobortis nibh faucibus. Vestibulum in urna pretium, convallis tellus vel, tincidunt quam. Donec ut magna quis justo vestibulum faucibus quis at velit. Aliquam laoreet ligula congue nisi dignissim, eu vestibulum urna dignissim.

  Donec vehicula eleifend est quis malesuada. Nam tristique placerat eros et semper. Mauris vel risus adipiscing, faucibus magna in, commodo dui. Aliquam sagittis non nibh ut faucibus. Nunc blandit orci et porttitor elementum. Aenean commodo nisi in facilisis tempus. Duis arcu eros, vehicula vitae auctor nec, vestibulum ac sem. Proin sed feugiat turpis. Vivamus aliquet tincidunt vestibulum. Cras rhoncus mauris libero, ut porttitor ante hendrerit sit amet. Proin ultrices rhoncus iaculis. Etiam eget lectus metus. Nullam varius metus euismod risus consequat imperdiet.

  Vivamus et accumsan magna. Ut arcu sapien, vehicula at nisi et, tincidunt consectetur turpis. Pellentesque auctor nibh vel diam fermentum viverra. In elementum tortor diam, in tincidunt orci sollicitudin feugiat. Fusce volutpat vulputate tortor, eu feugiat tellus vestibulum sed. Vivamus fringilla erat ante, vitae volutpat quam pulvinar vel. Maecenas nec lectus nec dolor ornare consectetur.

  Follow

  Vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia conseq…

  /minutes-of-2014-05-03
Mario Minstreel

  /chat-mario-minstreel
Star Alliance Officially Opens New Lounge At São Paulo - Guarulhos Airport Terminal 3

  Star Alliance officially opened its new Lounge at São Paulo –Guarulhos Airport, Terminal 3 today. About 1,350 square me…

  /news-press-1
KLM to give Edmonton only route to mainland Europe CrewTerminal 2

  Dutch carrier KLM will add Edmonton to its North American route map, announcing plans for nonstop service to Amsterdam.

  /hot-news2
Air France A380 Turns Back to Paris After Turbulence Hurts CrewTerminal 2

  An Airbus A380 superjumbo operated by Air France (AF) headed to New York’s JFK airport from Paris was forced to turn ba…

  /hot-news1
Statistiken, Verzeichnisse, Termine

  /01.02
Minutes of the Federal Open Market Committee June 17–18, 2014

  # Minutes of the Federal Open Market Committee June 17–18, 2014

  A meeting of the Federal Open Market Committee was held in the offices of the Board of Governors of the Federal Reserve System in Washington, D.C., on Tuesday, June 17, 2014, at 10:00 a.m. and continued on Wednesday, June 18, 2014, at 9:00 a.m.

  PRESENT:

  - Janet L. Yellen, Chair
  - William C. Dudley, Vice Chairman
  - Lael Brainard
  - Stanley Fischer
  - Richard W. Fisher
  - Narayana Kocherlakota
  - Loretta J. Mester
  - Charles I. Plosser
  - Jerome H. Powell
  - Daniel K. Tarullo

  In the agenda for this meeting, it was reported that Loretta J. Mester had been elected a member of the Federal Open Market Committee and that she had executed her oath of office.

  ## Developments in Financial Markets and the Federal Reserve’s Balance Sheet

  In a joint session of the Federal Open Market Committee (FOMC) and the Board of Governors of the Federal Reserve System, the deputy manager of the System Open Market Account (SOMA) reported on developments in domestic and foreign financial markets.

  The SOMA manager reported on the System open market operations during the period since the Committee met on April 29–30, 2014, outlined the testing of the Term Deposit Facility, described the results from the fixed rate overnight reverse repurchase agreement (ON RRP) operational exercise, and provided some possible options for adjusting the list of counterparties eligible to participate in ON RRP operations.

  The manager also noted the effects of recent foreign central bank policy actions on the yields on the international portion of the SOMA portfolio and discussed ongoing staff work on improving data collections regarding bank funding markets. By unanimous vote, the Committee ratified the Open Market Desk’s domestic transactions over the intermeeting period. There were no intervention operations in foreign currencies for the System’s ac- count over the intermeeting period.

  Follow

  A meeting of the Federal Open Market Committee was held in the offices of the Board of Governors of the Federal Reserve…

  /Minutes-of-the-Federal-Open-Market-Committee-June-2014
  Loading more search results…

Help